You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ka...@apache.org on 2010/03/16 14:25:47 UTC

svn commit: r923732 - /directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java

Author: kayyagari
Date: Tue Mar 16 13:25:46 2010
New Revision: 923732

URL: http://svn.apache.org/viewvc?rev=923732&view=rev
Log:
o removed NamingException
o updated isSchemaSubentry() method to throw LdapException

Modified:
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java?rev=923732&r1=923731&r2=923732&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/SchemaService.java Tue Mar 16 13:25:46 2010
@@ -1,9 +1,8 @@
 package org.apache.directory.server.core.schema;
 
 
-import javax.naming.NamingException;
-
 import org.apache.directory.server.core.entry.ServerEntry;
+import org.apache.directory.shared.ldap.exception.LdapException;
 import org.apache.directory.shared.ldap.schema.SchemaManager;
 
 
@@ -15,9 +14,9 @@ public interface SchemaService
      * 
      * @param dnString The DN we want to check
      * @return <code>true</code> if the given DN is the Schema subentry DN
      * @throws NamingException If the given DN is not valid
      */
-    boolean isSchemaSubentry( String dnString ) throws NamingException;
+    boolean isSchemaSubentry( String dnString ) throws LdapException;
 
 
     /**
@@ -44,7 +43,7 @@ public interface SchemaService
      * A seriously unsafe (unsynchronized) means to access the schemaSubentry.
      *
      * @return the schemaSubentry
-     * @throws NamingException if there is a failure to access schema timestamps
+     * @throws Exception if there is a failure to access schema timestamps
      */
     ServerEntry getSubschemaEntryImmutable() throws Exception;
 
@@ -53,7 +52,7 @@ public interface SchemaService
      * A seriously unsafe (unsynchronized) means to access the schemaSubentry.
      *
      * @return the schemaSubentry
-     * @throws NamingException if there is a failure to access schema timestamps
+     * @throws Exception if there is a failure to access schema timestamps
      */
     ServerEntry getSubschemaEntryCloned() throws Exception;
 
@@ -64,7 +63,7 @@ public interface SchemaService
      *
      * @param ids the ids of the attributes that should be returned from a search
      * @return the subschema entry with the ids provided
-     * @throws NamingException if there are failures during schema info access
+     * @throws Exception if there are failures during schema info access
      */
     ServerEntry getSubschemaEntry( String[] ids ) throws Exception;
 }
@@ -15,9 +14,9 @@ public interface SchemaService
      * @param dnString The DN we want to check
      * @return <code>true</code> if the given DN is the Schema subentry DN
-     * @throws NamingException If the given DN is not valid
+     * @throws LdapException If the given DN is not valid
      */
\ No newline at end of file